@@ -1,17 +1,10 @@
 /**
- * Copyright (C) 2019  The Software Heritage developers
+ * Copyright (C) 2019-2022  The Software Heritage developers
  * See the AUTHORS file at the top-level directory of this distribution
  * License: GNU Affero General Public License version 3, or any later version
  * See top-level LICENSE file for more information
  */
 
-import axios from 'axios';
-
-export async function httpGetJson(url) {
-  const response = await axios.get(url);
-  return response.data;
-}
-
 /**
  * Converts string with Time information
  * to an object with Time information
@@ -29,7 +22,8 @@ export function getTime(text) {
     monthName: date.toLocaleString('en', {month: 'long'}),
     year: date.getUTCFullYear(),
     hours: pad(date.getUTCHours()),
-    minutes: pad(date.getUTCMinutes())
+    minutes: pad(date.getUTCMinutes()),
+    seconds: pad(date.getUTCSeconds())
   };
 
   return time;
