@@ -1,15 +1,16 @@
-# Copyright (C) 2018-2019  The Software Heritage developers
+# Copyright (C) 2018-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from rest_framework.request import Request
+
 from swh.web.api.apidoc import api_doc, format_docstring
 from swh.web.api.apiurls import api_route
 from swh.web.api.utils import enrich_snapshot
 from swh.web.api.views.utils import api_lookup
-from swh.web.common import archive
-from swh.web.common.utils import reverse
 from swh.web.config import get_config
+from swh.web.utils import archive, reverse
 
 
 @api_route(
@@ -17,9 +18,9 @@ from swh.web.config import get_config
     "api-1-snapshot",
     checksum_args=["snapshot_id"],
 )
-@api_doc("/snapshot/")
+@api_doc("/snapshot/", category="Archive")
 @format_docstring()
-def api_snapshot(request, snapshot_id):
+def api_snapshot(request: Request, snapshot_id: str):
     """
     .. http:get:: /api/1/snapshot/(snapshot_id)/
 
@@ -72,8 +73,8 @@ def api_snapshot(request, snapshot_id):
 
     branches_from = request.GET.get("branches_from", "")
     branches_count = int(request.GET.get("branches_count", snapshot_content_max_size))
-    target_types = request.GET.get("target_types", None)
-    target_types = target_types.split(",") if target_types else None
+    target_types_str = request.GET.get("target_types", None)
+    target_types = target_types_str.split(",") if target_types_str else None
 
     results = api_lookup(
         archive.lookup_snapshot,
@@ -95,8 +96,8 @@ def api_snapshot(request, snapshot_id):
             url_args={"snapshot_id": snapshot_id},
             query_params={
                 "branches_from": results["next_branch"],
-                "branches_count": branches_count,
-                "target_types": target_types,
+                "branches_count": str(branches_count),
+                "target_types": ",".join(target_types) if target_types else None,
             },
             request=request,
         )
