@@ -8,4 +8,4 @@ from django.apps import AppConfig
 
 class InboundEmailConfig(AppConfig):
     default_auto_field = "django.db.models.BigAutoField"
-    name = "inbound_email"
+    name = "swh.web.inbound_email"
