@@ -1,4 +1,4 @@
-# Copyright (C) 2019  The Software Heritage developers
+# Copyright (C) 2019-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU Affero General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -12,5 +12,9 @@ email = "admin@swh-web.org"
 
 User = get_user_model()
 
-if not User.objects.filter(username=username).exists():
-    User.objects.create_superuser(username, email, password)
+try:
+    user = User.objects.filter(username=username).get()
+except User.DoesNotExist:
+    user = User.objects.create_superuser(username, email, password)
+
+assert user.is_staff is True
